#! /bin/bash

# increase the number of file handles
ulimit -S -n 2000

# get the full path to the current directory without relying 
# on dirname which returns the relative directory
dir="${0%/*}"

# get the "Darwin" version of the os
version=$(expr "$(uname -r)" : "\([0-9]*\)")

# mac os x 10.4 is the same as Darwin 8 (see http://en.wikipedia.org/wiki/Mac_OS_X_v10.4)
# 10.3 started to support Authorization Services, but gcc can only cross compile back to 10.4
# unfortunately, older versions don't seem to recognize programs compiled on 10.6.
is_old_version=$(expr $version "<=" 9)


# use the system's java application stub
JavaAdminBin=$dir/JavaAdmin.bin
JavaAppBin=$dir/JavaApp.bin
LocalJavaAppStub=/System/Library/Frameworks/JavaVM.framework/Resources/MacOS/JavaApplicationStub
DefaultHDJavaAppStub="/Volumes/Macintosh HD$LocalJavaAppStub"
VolumesJavaAppStub="/Volumes$LocalJavaAppStub"
if [ -e "$LocalJavaAppStub" ] ; then
    cp "$LocalJavaAppStub" "$JavaAppBin"
elif [ -e "$DefaultHDJavaAppStub" ] ; then
    cp "$DefaultHDJavaAppStub" "$JavaAppBin"
elif [ -e "$VolumesJavaAppStub" ] ; then
    cp "$VolumesJavaAppStub" "$JavaAppBin"
fi

# expr returns a string of 0 or 1
if [ "$is_old_version" == "1" ] ; then
    # start the java app as the current user
    cmd=$JavaAppBin
else
    # set the temp directory to resolve an intermittent Apple bug
    # http://lists.apple.com/archives/apple-cdsa/2008/Mar/msg00014.html
    mkdir ~/.tmp_launch
    TMPDIR=~/.tmp_launch
    export TMPDIR
    
    # start the java app with admin privileges
    cmd=$JavaAdminBin
fi

# run the app from the same process
exec "$cmd" "$@"

